# Contributing

Contributions are welcome, and they are greatly appreciated! Every little bit
helps, and credit will always be given.

You can contribute in many ways:

## Report Bugs

Report bugs at <https://github.com/darosio/clophfit/issues>.

If you are reporting a bug, please include:

- Your operating system name and version.
- Any details about your local setup that might be helpful in troubleshooting.
- Detailed steps to reproduce the bug.

## Fix Bugs

Look through the GitHub issues for bugs. Anything tagged with \"bug\" is open to
whoever wants to implement it.

## Implement Features

Look through the GitHub issues for features. Anything tagged with \"feature\" is
open to whoever wants to implement it.

## Write Documentation

clophfit could always use more documentation, whether as part of the official
clophfit docs, in docstrings, or even on the web in blog posts, articles, and
such.

## Submit Feedback

The best way to send feedback is to file an issue at
<https://github.com/darosio/clophfit/issues>.

If you are proposing a feature:

- Explain in detail how it would work.
- Keep the scope as narrow as possible, to make it easier to implement.
- Remember that this is a volunteer-driven project, and that contributions are
  welcome :)
